@@ -25,6 +25,7 @@
 # HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
 
+import ConfigParser
 import hubzero.config.hubzerositeconfig
 import hubzero.data.db
 import re
@@ -178,3 +179,25 @@ def setPluginEnabled(pluginFolder, pluginElement, enable):
 	sql = "UPDATE jos_plugins set published = %s WHERE `folder` = %s AND `element` = %s"
 	data = (enable, pluginFolder, pluginElement)
 	db.execQuery(sql, data)	
+
+
+def getHubSiteConfig(hubname, sectionName, valueName):
+	"""
+	get a value from the /etc/hubzero-cms/HUBNAME.conf file
+	"""
+	filename = "/etc/hubzero-cms/" + hubname + ".conf"
+	
+	if not os.path.exists(filename):
+		print "Cannot find " + filename
+	
+	hubzeroCMSConfig = ConfigParser.ConfigParser()
+	hubzeroCMSConfig.readfp(open(filename))
+	
+	try:
+		rv = hubzeroCMSConfig.get(sectionName, valueName)
+	except ConfigParser.NoOptionError:
+		rv = ""
+	
+	return rv
+
+
